@@ -1,9 +1,8 @@
-import warnings
 from .video import *
 from .movementdetection import *
 from .backgroundsubtraction import *
 from .coordinatearrays import *
-from .frameprocessing import *
+from .frames import *
 from .utils import *
 try:
     import pypylon
